@@ -43,10 +43,6 @@
  */
 #if JS_HAS_FILE_OBJECT
 
-#ifdef OSSP
-#define XP_UNIX
-#endif
-
 #include "jsstddef.h"
 
 /* ----------------- Platform-specific includes and defines ----------------- */
@@ -95,6 +91,9 @@
 #include "jsscript.h"
 #include "jsstr.h"
 #include "jsutil.h" /* Added by JSIFY */
+#ifdef OSSP /* CLEANUP */
+#include "jsfile.h"
+#endif
 #include <string.h>
 
 /* NSPR dependencies */
@@ -2277,9 +2276,18 @@ file_toURL(JSContext *cx, JSObject *obj, uintN argc, jsval *argv, jsval *rval)
     sprintf(url, "file://%s", file->path);
     /* TODO: js_escape in jsstr.h may go away at some point */
 
+#ifdef OSSP /* BUGFIX */
+{
+    size_t len = strlen(url);
+    urlChars = js_InflateString(cx, url, &len);
+    if (urlChars == NULL) return JS_FALSE;
+    *rval = STRING_TO_JSVAL(js_NewString(cx, urlChars, len, 0));
+}
+#else
     urlChars = js_InflateString(cx, url, strlen(url));
     if (urlChars == NULL) return JS_FALSE;
     *rval = STRING_TO_JSVAL(js_NewString(cx, urlChars, strlen(url), 0));
+#endif
     if (!js_str_escape(cx, obj, 0, rval, rval)) return JS_FALSE;
 
     return JS_TRUE;
@@ -2354,6 +2362,9 @@ js_NewFileObject(JSContext *cx, char *filename)
 }
 
 /* Internal function, used for cases which NSPR file support doesn't cover */
+#ifdef OSSP /* CLEANUP */
+static
+#endif
 JSObject*
 js_NewFileObjectFromFILE(JSContext *cx, FILE *nativehandle, char *filename,
     int32 mode, JSBool open, JSBool randomAccess)
@@ -2400,7 +2411,6 @@ file_constructor(JSContext *cx, JSObject *obj, uintN argc, jsval *argv,
         obj = JS_NewObject(cx, &file_class, NULL, NULL);
         if (!obj)
             return JS_FALSE;
-        *rval = OBJECT_TO_JSVAL(obj);
     }
 
     str = (argc == 0) 
@@ -2420,6 +2430,7 @@ file_constructor(JSContext *cx, JSObject *obj, uintN argc, jsval *argv,
 
     SECURITY_CHECK(cx, NULL, "constructor", file);
 
+    *rval = OBJECT_TO_JSVAL(obj);
     return JS_TRUE;
 }
 
@@ -2466,7 +2477,11 @@ enum file_tinyid {
     FILE_APPEND             = -19,
     FILE_REPLACE            = -20,
     FILE_AUTOFLUSH          = -21,
+#ifdef OSSP /* BUGFIX */
+    FILE_ISNATIVE           = -22
+#else
     FILE_ISNATIVE           = -22,
+#endif
 };
 
 static JSPropertySpec file_props[] = {
@@ -2862,18 +2877,18 @@ file_getProperty(JSContext *cx, JSObject *obj, jsval id, jsval *vp)
                     bytes = js_combinePath(cx, file->path, prop_name);
                     *vp = OBJECT_TO_JSVAL(js_NewFileObject(cx, bytes));
                     JS_free(cx, bytes);
-#ifdef OSSP
+#ifdef OSSP /* BUGFIX */
                     closedir(dir);
 #else
-                    PR_CloseDir(dir); /* XXX: bugfix */
+                    PR_CloseDir(dir);
 #endif
                     return JS_TRUE;
                 }
             }
-#ifdef OSSP
+#ifdef OSSP /* BUGFIX */
             closedir(dir);
 #else
-            PR_CloseDir(dir); /* XXX: bugfix */
+            PR_CloseDir(dir);
 #endif
         }
     }
